Dimension — csdmpy 0.1.1 documentation

# Dimension

A generalized object describing a dimension of a multi-dimensional grid/space.

## Specialized Class

LinearDimension MonotonicDimension LabeledDimension

## Attributes

Name | Type | Description
--- | --- | ---
type | DimObjectSubtype | An enumeration literal with a valid dimension subtype.
label | String | Label of the dimension.
description | String | Description of the dimension.
application | Generic | Generic dictionary object containing application specific metadata describing the dimension.